# Install the info files for this package
if [ -x usr/bin/install-info ]
then
   usr/bin/install-info --info-dir=/usr/info /usr/info/gnat-style.info.gz 2>/dev/null
   usr/bin/install-info --info-dir=/usr/info /usr/info/gnat_rm.info.gz 2>/dev/null
   usr/bin/install-info --info-dir=/usr/info /usr/info/gnat_ug_unx.info.gz 2>/dev/null
   usr/bin/install-info --info-dir=/usr/info /usr/info/gnat_ug_vms.info.gz 2>/dev/null
   usr/bin/install-info --info-dir=/usr/info /usr/info/gnat_ug_vxw.info.gz 2>/dev/null
   usr/bin/install-info --info-dir=/usr/info /usr/info/gnat_ug_wnt.info.gz 2>/dev/null
fi

